Wrap a pair of sodium keys for asymmetric encryption. You should pass your private key and the public key of the person that you are communicating with.
Arguments
- pub
A sodium public key. This is either a raw vector of length 32 or a path to file containing the contents of the key (written by
writeBin()).- key
A sodium private key. This is either a raw vector of length 32 or a path to file containing the contents of the key (written by
writeBin()).- authenticated
Logical, indicating if authenticated encryption (via
sodium::auth_encrypt()/sodium::auth_decrypt()) should be used. IfFALSEthensodium::simple_encrypt()/sodium::simple_decrypt()will be used. The difference is that withauthenticated = TRUEthe message is signed with your private key so that tampering with the message will be detected.
Details
NOTE: the order here (pub, key) is very important; if the wrong order is used you cannot decrypt things. Unfortunately because sodium keys are just byte sequences there is nothing to distinguish the public and private keys so this is a pretty easy mistake to make.
See also
keypair_openssl() for a similar function using
openssl keypairs
Examples
# Generate two keypairs, one for Alice, and one for Bob
key_alice <- sodium::keygen()
pub_alice <- sodium::pubkey(key_alice)
key_bob <- sodium::keygen()
pub_bob <- sodium::pubkey(key_bob)
# Alice wants to send Bob a message so she creates a key pair with
# her private key and bob's public key (she does not have bob's
# private key).
pair_alice <- cyphr::keypair_sodium(pub = pub_bob, key = key_alice)
# She can then encrypt a secret message:
secret <- cyphr::encrypt_string("hi bob", pair_alice)
secret
#> [1] 35 d9 b1 eb 2a 07 eb f6 20 b9 44 cf 0c fb 65 ae c8 59 93 06 ac 3b aa 78 99
#> [26] 20 d7 8a e2 0c 31 7e 2d 0f 5a 3d 70 0d 80 5d 1a 37 1b e0 a5 40
# Bob wants to read the message so he creates a key pair using
# Alice's public key and his private key:
pair_bob <- cyphr::keypair_sodium(pub = pub_alice, key = key_bob)
cyphr::decrypt_string(secret, pair_bob)
#> [1] "hi bob"